@@ -8,7 +8,7 @@
  *
  *****************************************************************************/
 
-// $Id: kupubasetools.js 27123 2006-05-12 10:19:22Z duncan $
+// $Id: kupubasetools.js 30992 2006-08-04 12:24:19Z duncan $
 
 
 //----------------------------------------------------------------------------
@@ -338,8 +338,8 @@ function KupuUI(textstyleselectid) {
         parastyles['p'] = 0;
         while (options.length > 1) {
             opt = options[1];
-            var v = opt.value.toLowerCase();
-            if (/^thead|tbody|table|t[rdh]\b/.test(v)) {
+            var v = opt.value;
+            if (/^thead|tbody|table|t[rdh]\b/i.test(v)) {
                 var otable = tableoptions;
                 var styles = tablestyles;
             } else {
@@ -898,7 +898,7 @@ function LinkTool() {
             } else {
                 linkel.removeAttribute('title');
             }
-            if (target && target != '') {
+            if (target) {
                 linkel.setAttribute('target', target);
             }
             else {
